@@ -17,7 +17,7 @@ def load_vocab(path):
   return vocab
 
 
-def load_model(model_weights_path:str):
+def load_model(model_weights_path:str = "better2129Mar21.pt"):
     """
         Need the [hinglish_vocab.pkl, hindi_vocab.pkl] files in the same directory as the code
     """
